@@ -13,12 +13,12 @@ sub get_pid : Job {
     return $self->pid;
 }
 
-sub ten_childs : Job : MinChilds(10) : MaxChilds(10) {
+sub ten_processes : Job : MinProcesses(10) : MaxProcesses(10) {
     my ( $self, $job, $workload ) = @_;
     return $self->pid;
 }
 
-sub sleeper : Job : MinChilds(2) : MaxChilds(6) {
+sub sleeper : Job : MinProcesses(2) : MaxProcesses(6) {
     my ( $self, $job, $workload ) = @_;
     my ( $sleep, $time ) = split /:/, $job->workload;
     sleep($sleep) if $sleep;
